==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance.md <==
# AmazonEc2HabanaGaudiInstance


```text
aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance
```

```text
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')
```



| Illustration | AmazonEc2HabanaGaudiInstance | AmazonEc2HabanaGaudiInstanceCard | AmazonEc2HabanaGaudiInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance.png) | ![illustration for AmazonEc2HabanaGaudiInstance](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance.Local.png) | ![illustration for AmazonEc2HabanaGaudiInstanceCard](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstanceCard.Local.png) | ![illustration for AmazonEc2HabanaGaudiInstanceGroup](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstanceGroup.Local.png) |




## AmazonEc2HabanaGaudiInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstance('AmazonEc2HabanaGaudiInstance', 'Amazon Ec2 Habana Gaudi Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstance('AmazonEc2HabanaGaudiInstance', 'Amazon Ec2 Habana Gaudi Instance', 'an optional tech label')
@enduml
```

## AmazonEc2HabanaGaudiInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceCard('AmazonEc2HabanaGaudiInstanceCard', 'Amazon Ec2 Habana Gaudi Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceCard('AmazonEc2HabanaGaudiInstanceCard', 'Amazon Ec2 Habana Gaudi Instance Card', 'an optional description')
@enduml
```

## AmazonEc2HabanaGaudiInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceGroup('AmazonEc2HabanaGaudiInstanceGroup', 'Amazon Ec2 Habana Gaudi Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceGroup('AmazonEc2HabanaGaudiInstanceGroup', 'Amazon Ec2 Habana Gaudi Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance.md <==
# AmazonEc2HabanaGaudiInstance


```text
aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance
```

```text
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')
```



| Illustration | AmazonEc2HabanaGaudiInstance | AmazonEc2HabanaGaudiInstanceCard | AmazonEc2HabanaGaudiInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance.png) | ![illustration for AmazonEc2HabanaGaudiInstance](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance.Local.png) | ![illustration for AmazonEc2HabanaGaudiInstanceCard](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstanceCard.Local.png) | ![illustration for AmazonEc2HabanaGaudiInstanceGroup](../../../aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstanceGroup.Local.png) |




## AmazonEc2HabanaGaudiInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstance('AmazonEc2HabanaGaudiInstance', 'Amazon Ec2 Habana Gaudi Instance', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstance
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstance('AmazonEc2HabanaGaudiInstance', 'Amazon Ec2 Habana Gaudi Instance', 'an optional tech label', 'an optional description')
@enduml
```

## AmazonEc2HabanaGaudiInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceCard('AmazonEc2HabanaGaudiInstanceCard', 'Amazon Ec2 Habana Gaudi Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceCard
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceCard('AmazonEc2HabanaGaudiInstanceCard', 'Amazon Ec2 Habana Gaudi Instance Card', 'an optional description')
@enduml
```

## AmazonEc2HabanaGaudiInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceGroup('AmazonEc2HabanaGaudiInstanceGroup', 'Amazon Ec2 Habana Gaudi Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonEc2HabanaGaudiInstanceGroup
include('aws-q2-2022/Resource/Compute/AmazonEc2HabanaGaudiInstance')

' renders the element
AmazonEc2HabanaGaudiInstanceGroup('AmazonEc2HabanaGaudiInstanceGroup', 'Amazon Ec2 Habana Gaudi Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
